@@ -1,13 +1,6 @@
 use std::collections::HashMap;
 use crate::specification::*;
 use crate::namemap::*;
-use crate::Logger;
-
-struct DummyLogger {}
-impl Logger for DummyLogger {
-    fn log_message(&mut self, _: String) {}
-}
-
 
 
 pub(crate) fn merge_modules(orig_module: &mut Module, merge_module: &mut Module) {
@@ -109,9 +102,9 @@ fn merge_memory_layout(orig_module: &mut Module, merge_module: &mut Module) {
 // ------------------------ MEMORY_SEGMENT ------------------------
 
 fn merge_memory_segment(orig_module: &mut Module, merge_module: &mut Module) {
-    let mut logger = DummyLogger{};
-    let orig_map = build_namemap_memory_segment(orig_module, &mut logger);
-    let merge_map = build_namemap_memory_segment(merge_module, &mut logger);
+    let mut log_msgs = Vec::<String>::new();
+    let orig_map = build_namemap_memory_segment(orig_module, &mut log_msgs);
+    let merge_map = build_namemap_memory_segment(merge_module, &mut log_msgs);
     let (merge_action, rename_table) = calculate_item_actions(orig_map, merge_map);
 
     rename_memory_segments(merge_module, rename_table);
@@ -184,9 +177,9 @@ fn merge_if_data(orig_module: &mut Module, merge_module: &mut Module) {
 // ------------------------ UNIT ------------------------
 
 fn merge_unit(orig_module: &mut Module, merge_module: &mut Module) {
-    let mut logger = DummyLogger{};
-    let orig_map = build_namemap_unit(orig_module, &mut logger);
-    let merge_map = build_namemap_unit(merge_module, &mut logger);
+    let mut log_msgs = Vec::<String>::new();
+    let orig_map = build_namemap_unit(orig_module, &mut log_msgs);
+    let merge_map = build_namemap_unit(merge_module, &mut log_msgs);
     let (merge_action, rename_table) = calculate_item_actions(orig_map, merge_map);
 
     rename_units(merge_module, rename_table);
@@ -222,9 +215,9 @@ fn rename_units(merge_module: &mut Module, rename_table: HashMap<String, String>
 // ------------------------ COMPU_TAB / COMPU_VTAB / COMPU_VTAB_RANGE ------------------------
 
 fn merge_compu_tab(orig_module: &mut Module, merge_module: &mut Module) {
-    let mut logger = DummyLogger{};
-    let orig_map = build_namemap_compu_tab(orig_module, &mut logger);
-    let merge_map = build_namemap_compu_tab(merge_module, &mut logger);
+    let mut log_msgs = Vec::<String>::new();
+    let orig_map = build_namemap_compu_tab(orig_module, &mut log_msgs);
+    let merge_map = build_namemap_compu_tab(merge_module, &mut log_msgs);
     let (merge_action, rename_table) = calculate_item_actions(orig_map, merge_map);
 
     rename_compu_tabs(merge_module, rename_table);
@@ -284,9 +277,9 @@ fn rename_compu_tabs(merge_module: &mut Module, rename_table: HashMap<String, St
 // ------------------------ COMPU_METHOD ------------------------
 
 fn merge_compu_method(orig_module: &mut Module, merge_module: &mut Module) {
-    let mut logger = DummyLogger{};
-    let orig_map = build_namemap_compu_method(orig_module, &mut logger);
-    let merge_map = build_namemap_compu_method(merge_module, &mut logger);
+    let mut log_msgs = Vec::<String>::new();
+    let orig_map = build_namemap_compu_method(orig_module, &mut log_msgs);
+    let merge_map = build_namemap_compu_method(merge_module, &mut log_msgs);
     let (merge_action, rename_table) = calculate_item_actions(orig_map, merge_map);
 
     rename_compu_methods(merge_module, rename_table);
@@ -337,9 +330,9 @@ fn rename_compu_methods(merge_module: &mut Module, rename_table: HashMap<String,
 // ------------------------ RECORD_LAYOUT ------------------------
 
 fn merge_record_layout(orig_module: &mut Module, merge_module: &mut Module) {
-    let mut logger = DummyLogger{};
-    let orig_map = build_namemap_record_layout(orig_module, &mut logger);
-    let merge_map = build_namemap_record_layout(merge_module, &mut logger);
+    let mut log_msgs = Vec::<String>::new();
+    let orig_map = build_namemap_record_layout(orig_module, &mut log_msgs);
+    let merge_map = build_namemap_record_layout(merge_module, &mut log_msgs);
     let (merge_action, rename_table) = calculate_item_actions(orig_map, merge_map);
 
     rename_record_layouts(merge_module, rename_table);
@@ -397,12 +390,12 @@ fn merge_mod_common(orig_module: &mut Module, merge_module: &mut Module) {
 // ------------------------ AXIS_PTS, CHARACTERISTIC, MEASUREMENT, INSTANCE, BLOB and FUNCTION ------------------------
 
 fn merge_objects(orig_module: &mut Module, merge_module: &mut Module) {
-    let mut logger = DummyLogger{};
-    let orig_map = build_namemap_object(orig_module, &mut logger);
-    let merge_map = build_namemap_object(merge_module, &mut logger);
+    let mut log_msgs = Vec::<String>::new();
+    let orig_map = build_namemap_object(orig_module, &mut log_msgs);
+    let merge_map = build_namemap_object(merge_module, &mut log_msgs);
     let (object_merge_action, object_rename_table) = calculate_item_actions(orig_map, merge_map);
-    let orig_map = build_namemap_function(orig_module, &mut logger);
-    let merge_map = build_namemap_function(merge_module, &mut logger);
+    let orig_map = build_namemap_function(orig_module, &mut log_msgs);
+    let merge_map = build_namemap_function(merge_module, &mut log_msgs);
     let (function_merge_action, function_rename_table) = calculate_item_actions(orig_map, merge_map);
 
     rename_objects(merge_module, object_rename_table);
@@ -624,9 +617,9 @@ fn rename_functions(merge_module: &mut Module, rename_table: HashMap<String, Str
 // ------------------------ GROUP ------------------------
 
 fn merge_group(orig_module: &mut Module, merge_module: &mut Module) {
-    let mut logger = DummyLogger{};
-    let orig_map = build_namemap_group(orig_module, &mut logger);
-    let merge_map = build_namemap_group(merge_module, &mut logger);
+    let mut log_msgs = Vec::<String>::new();
+    let orig_map = build_namemap_group(orig_module, &mut log_msgs);
+    let merge_map = build_namemap_group(merge_module, &mut log_msgs);
     let (merge_action, rename_table) = calculate_item_actions(orig_map, merge_map);
 
     rename_groups(merge_module, rename_table);
@@ -663,9 +656,9 @@ fn rename_groups(merge_module: &mut Module, rename_table: HashMap<String, String
 // ------------------------ FRAME ------------------------
 
 fn merge_frame(orig_module: &mut Module, merge_module: &mut Module) {
-    let mut logger = DummyLogger{};
-    let orig_map = build_namemap_frame(orig_module, &mut logger);
-    let merge_map = build_namemap_frame(merge_module, &mut logger);
+    let mut log_msgs = Vec::<String>::new();
+    let orig_map = build_namemap_frame(orig_module, &mut log_msgs);
+    let merge_map = build_namemap_frame(merge_module, &mut log_msgs);
     let (merge_action, rename_table) = calculate_item_actions(orig_map, merge_map);
 
     rename_frames(merge_module, rename_table);
@@ -693,9 +686,9 @@ fn rename_frames(merge_module: &mut Module, rename_table: HashMap<String, String
 // ------------------------ TRANSFORMER ------------------------
 
 fn merge_transformer(orig_module: &mut Module, merge_module: &mut Module) {
-    let mut logger = DummyLogger{};
-    let orig_map = build_namemap_transformer(orig_module, &mut logger);
-    let merge_map = build_namemap_transformer(merge_module, &mut logger);
+    let mut log_msgs = Vec::<String>::new();
+    let orig_map = build_namemap_transformer(orig_module, &mut log_msgs);
+    let merge_map = build_namemap_transformer(merge_module, &mut log_msgs);
     let (merge_action, rename_table) = calculate_item_actions(orig_map, merge_map);
 
     rename_transformers(merge_module, rename_table);
@@ -726,9 +719,9 @@ fn rename_transformers(merge_module: &mut Module, rename_table: HashMap<String,
 // ------------------------ TYPEDEF_* ------------------------
 
 fn merge_typedef(orig_module: &mut Module, merge_module: &mut Module) {
-    let mut logger = DummyLogger{};
-    let orig_map = build_namemap_typedef(orig_module, &mut logger);
-    let merge_map = build_namemap_typedef(merge_module, &mut logger);
+    let mut log_msgs = Vec::<String>::new();
+    let orig_map = build_namemap_typedef(orig_module, &mut log_msgs);
+    let merge_map = build_namemap_typedef(merge_module, &mut log_msgs);
     let (merge_action, rename_table) = calculate_item_actions(orig_map, merge_map);
 
     rename_typedefs(merge_module, rename_table);
